@@ -11,7 +11,7 @@ from operator import itemgetter
 
 #####################################################################
 class MapFunctions(object):
-    def __init__(self, pdb_code, mobj,pobj, interp_method):
+    def __init__(self, pdb_code, mobj,pobj, interp_method,degree=-1):
         # PUBLIC INTERFACE
         self.pdb_code = pdb_code        
         self.mobj = mobj
@@ -22,8 +22,9 @@ class MapFunctions(object):
         else:
             for i in range(len(self.mobj.values)):
                 self.main_interper_vals.append(self.mobj.values[i])
-            self.interper = pol.create_interpolator(interp_method,self.main_interper_vals,self.mobj.F,self.mobj.M,self.mobj.S,log_level=1)
+            self.interper = pol.create_interpolator(interp_method,self.main_interper_vals,self.mobj.F,self.mobj.M,self.mobj.S,log_level=1,degree=degree)
         self.interp_method = interp_method
+        self.degree = degree
         self.fo=2
         self.fc=-1
         self.crs_spc = None
@@ -37,10 +38,11 @@ class MapFunctions(object):
         self.crs_spc = crs.CrsTransform(dim_order, crs_starts, axis_sampling, map2crs, cell_dims, angles)        
         
     
-    def make_interper_if_needed(self,interp_method,log_level,fo,fc):
-        if self.interp_method != interp_method and self.mobj.diff_values == []:#then the method has changed but it is em with no diffs
-            self.interper = pol.create_interpolator(interp_method,self.main_interper_vals,self.mobj.F,self.mobj.M,self.mobj.S,log_level=log_level)
-        elif self.interp_method != interp_method or (self.fo != fo or self.fc != fc and self.mobj.diff_values != []):            
+    def make_interper_if_needed(self,interp_method,log_level,fo,fc,degree):
+        change_degree = (degree != -1) and (degree != self.degree)
+        if (self.interp_method != interp_method or change_degree) and self.mobj.diff_values == []:#then the method has changed but it is em with no diffs
+            self.interper = pol.create_interpolator(interp_method,self.main_interper_vals,self.mobj.F,self.mobj.M,self.mobj.S,degree=degree,log_level=log_level)
+        elif (self.interp_method != interp_method or change_degree) or (self.fo != fo or self.fc != fc and self.mobj.diff_values != []):            
             if self.mobj.diff_values != []: #we can't change the fo and fc if thee is no diff
                 interper_vals = []
                 vs, ds = 0,0
@@ -52,13 +54,15 @@ class MapFunctions(object):
                 for i in range(len(self.mobj.values)):
                     interper_vals.append(vs*self.mobj.values[i] + ds*self.mobj.diff_values[i])
                 self.interper = pol.create_interpolator(interp_method,interper_vals,self.mobj.F,self.mobj.M,self.mobj.S,log_level=log_level)
-                self.interp_method = interp_method
-                self.fo = fo
-                self.fc = fc
+        self.interp_method = interp_method
+        self.fo = fo
+        self.fc = fc
+        if change_degree:
+            self.degree = degree
     
-    def get_slice(self,central, linear, planar, width, samples, interp_method, deriv=0, fo=2,fc=-1,log_level=0):
+    def get_slice(self,central, linear, planar, width, samples, interp_method, deriv=0, fo=2,fc=-1,log_level=0,degree=-1):
         # change interpolator if necessary
-        self.make_interper_if_needed(interp_method,log_level,fo,fc)                
+        self.make_interper_if_needed(interp_method,log_level,fo,fc,degree)                
         #############        
         # objects needed
         spc = space.SpaceTransform(central, linear, planar)
@@ -82,9 +86,9 @@ class MapFunctions(object):
         vals = self.interper.get_projection(sliced.lower())        
         return vals
     
-    def get_atoms_projection(self, interp_method,log_level=0):
+    def get_atoms_projection(self, interp_method,degree=-1,log_level=0):
         atoms = self.pobj.get_atom_coords()
-        self.make_interper_if_needed(interp_method,log_level,2,-1)
+        self.make_interper_if_needed(interp_method,log_level,2,-1,degree)
         crss = []        
         for atm in atoms:
             crs_coord = self.get_crs(atm)
